@@ -22,7 +22,7 @@ x = Sampler(energy_muon, baseline)
 ###########################
 
 # Smear the stored muon energy by 10% uniform spread
-#x.set_accelerator_energy(spread=0.1 * energy_muon) # GeV
+x.set_accelerator_energy(spread=0.1 * energy_muon) # GeV
 
 #  Integrate over the detector volume
 my_mass = 1.3 # kt
