@@ -7,7 +7,8 @@ import numpy as np
 from Constants import MUON_MASS
 
 
-def compute_neutrino_flux(my_input, N_mu=1.8e18):
+def compute_neutrino_flux(my_input, N_mu=1.8e18, E_min=0.5, E_max=3.8,
+                          steps=100):
     """Compute neutrino fluxes using double differential cross section
 
     We assume unpolarized.
@@ -16,7 +17,7 @@ def compute_neutrino_flux(my_input, N_mu=1.8e18):
     hep-ph/0002108.  For a derivation, see Jian Tang's thesis.
     """
 
-    nu_energies = np.arange(0.3, 3.8, 0.1)
+    nu_energies = np.linspace(E_min, E_max, steps)
     N_flux_bins = len(my_input)
 
     results = {'e_flux': {}, 'mu_flux': {}}
@@ -32,7 +33,7 @@ def compute_neutrino_flux(my_input, N_mu=1.8e18):
         # distance in km
         # angle in rad
 
-        distance = 1000 * distance  # m
+        distance = 1000 * distance  # km -> m
 
         for E_nu in nu_energies:
             E_nu = float(E_nu)
@@ -45,14 +46,14 @@ def compute_neutrino_flux(my_input, N_mu=1.8e18):
             beta = math.sqrt(1 - MUON_MASS ** 2 / E_mu ** 2)
 
             flux_e = 24.0 * N_mu
-            flux_e /= math.pi * distance ** 2 * MUON_MASS ** 6
+            flux_e /= (math.pi * distance ** 2 * MUON_MASS ** 6)
             flux_e *= E_mu ** 4 * y ** 2
             flux_e *= (1 - beta * math.cos(angle))
             flux_e *= (MUON_MASS ** 2 - 2 * E_mu ** 2 *
                                         y * (1 - beta * math.cos(angle)))
 
-            flux_mu = 4 * N_mu
-            flux_mu /= math.pi * distance ** 2 * MUON_MASS ** 6
+            flux_mu = 4.0 * N_mu
+            flux_mu /= (math.pi * distance ** 2 * MUON_MASS ** 6)
             flux_mu *= E_mu ** 4 * y ** 2
             flux_mu *= (1 - beta * math.cos(angle))
             flux_mu *= (3 * MUON_MASS ** 2 - 4 * E_mu ** 2 *
