@@ -1,6 +1,6 @@
 __author__ = 'tunnell'
 
-from Constants import AVOGADROS_NUMBER
+from Constants import AVOGADROS_NUMBER, GL, GR
 
 def CC(fluxes, mass=1):
     """Compute CC event rates
@@ -11,9 +11,9 @@ def CC(fluxes, mass=1):
     xsec = {}
     xsec['nubar'] = 0.34 * 10 ** -42 # units of m^2
     xsec['nu'] = 0.67 * 10 ** -42     # units of m^2
-
+    xsec['nuel'] = 1.72 * 10**-41 * 10**-4 * (GL**2 + 1./3 * GR**2)
+    
     E_range = {'min': None, 'max': None}
-    bins = {}
 
     interactions = {}
     for flavor, value in fluxes.iteritems():
@@ -24,17 +24,19 @@ def CC(fluxes, mass=1):
             if E_range['max'] is None or energy > E_range['max']:
                 E_range['max'] = energy
 
-            for nu_or_nubar in ['nu', 'nubar']:
+            for nu_or_nubar in xsec.keys():
                 key = (flavor, nu_or_nubar)
                 if key not in interactions:
                     interactions[key] = 0.0
-                    bins[key] = 0
 
                 my_int = mass * 10 ** 9 * AVOGADROS_NUMBER * xsec[nu_or_nubar]
                 my_int *= energy * flux
 
+                if nu_or_nubar == 'nuel':
+                    my_int *= 18 # number of electrons in LAr
+                    my_int /= 39.948 # atomic weight
+
                 interactions[key] += my_int
-                bins[key] += 1
 
     return interactions
 
